@@ -33,6 +33,8 @@
 #include <Rcpp/clone.h>
 #include <Rcpp/grow.h>
 #include <Rcpp/Dimension.h>
+
+#include <Rcpp/Symbol.h>
 #include <Rcpp/Environment.h>
 
 #include <Rcpp/Vector.h>
@@ -42,7 +44,6 @@
 #include <Rcpp/Promise.h>
 
 #include <Rcpp/XPtr.h>
-#include <Rcpp/Symbol.h>
 #include <Rcpp/DottedPairImpl.h>
 #include <Rcpp/Function.h>
 #include <Rcpp/Language.h>
@@ -54,10 +55,11 @@
 #include <Rcpp/StringTransformer.h>
 #include <Rcpp/Formula.h>
 #include <Rcpp/DataFrame.h>
-#include <Rcpp/Date.h>
-#include <Rcpp/DateVector.h>
-#include <Rcpp/Datetime.h>
-#include <Rcpp/DatetimeVector.h>
+
+#if !defined(RCPP_FORCE_OLD_DATE_DATETIME_VECTORS)
+  #define RCPP_NEW_DATE_DATETIME_VECTORS 1
+#endif
+#include <Rcpp/date_datetime/date_datetime.h>
 
 #include <Rcpp/Na_Proxy.h>
 
@@ -66,6 +68,8 @@
 
 #include <Rcpp/Nullable.h>
 
+#include <Rcpp/RNGScope.h>
+
 #ifndef RCPP_NO_SUGAR
 #include <Rcpp/sugar/sugar.h>
 #include <Rcpp/stats/stats.h>
@@ -80,4 +84,6 @@
 
 #include <Rcpp/platform/solaris.h>
 #include <Rcpp/api/meat/meat.h>
+
+#include <Rcpp/algorithm.h>
 #endif
