@@ -3,7 +3,7 @@
 //
 // is_reference.h: Rcpp R/C++ interface class library -- identifies if a type is a reference
 //
-// Copyright (C) 2010	Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2012 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -19,20 +19,17 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
-   
+
 #ifndef Rcpp__traits__remove_const_and_reference__h
 #define Rcpp__traits__remove_const_and_reference__h
 
-#include <Rcpp/traits/remove_const.h>
-#include <Rcpp/traits/remove_reference.h>
-
 namespace Rcpp{ namespace traits {
-	
+
 	template <typename T>
 	struct remove_const_and_reference {
 		typedef typename remove_const< typename remove_reference<T>::type >::type type ;
 	} ;
-	
+
 }}
 
 #endif
