@@ -64,22 +64,33 @@ using namespace Rcpp;
 namespace Rcpp {
 
     namespace internal {
-        namespace {
-            unsigned long RNGScopeCounter = 0;
-        }
+
+        int rngSynchronizationSuspended = 0;
 
         // [[Rcpp::register]]
         unsigned long enterRNGScope() {
-            if (RNGScopeCounter == 0) GetRNGstate();
-            RNGScopeCounter++;
-            return RNGScopeCounter;
+            if (rngSynchronizationSuspended == 0)
+                GetRNGstate();
+            return 0;
         }
 
         // [[Rcpp::register]]
         unsigned long exitRNGScope() {
-            RNGScopeCounter--;
-            if (RNGScopeCounter == 0) PutRNGstate();
-            return RNGScopeCounter;
+            if (rngSynchronizationSuspended == 0)
+                PutRNGstate();
+            return 0;
+        }
+
+        // [[Rcpp::register]]
+        unsigned long beginSuspendRNGSynchronization() {
+            ++rngSynchronizationSuspended;
+            return rngSynchronizationSuspended;
+        }
+
+        // [[Rcpp::register]]
+        unsigned long endSuspendRNGSynchronization() {
+            --rngSynchronizationSuspended;
+            return rngSynchronizationSuspended;
         }
 
         // [[Rcpp::register]]
